==> galio-framework-0.5.1.tgz: package/README.md <==
# [galio](https://www.galio.io) [![Tweet](https://img.shields.io/twitter/url/http/shields.io.svg?style=social&logo=twitter)](https://twitter.com/home?status=Galio,%20a%20free%20and%20beautiful%20UI%20framework%20https%3A//galio.io/%20%23reactnative%20%23react%20%23design%20%23developers%20%23freebie%20via%20%40galioframework)

[![GitHub issues](https://img.shields.io/github/issues/galio-org/galio.svg?style=popout)](https://github.com/galio-org/galio/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/galio-org/galio.svg)](https://github.com/galio-org/galio/issues?q=is%3Aissue+is%3Aclosed)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/galio-org/galio.svg)](https://github.com/galio-org/galio/pulls)
[![GitHub closed pull requests](https://img.shields.io/github/issues-pr-closed/galio-org/galio.svg)](https://github.com/galio-org/galio/pulls?q=is%3Apr+is%3Aclosed)
[![Gitter](https://badges.gitter.im/NIT-dgp/General.svg)](https://gitter.im/galio-community)
[![npm](https://img.shields.io/npm/dm/galio-framework.svg)](https://www.npmjs.com/package/galio-framework)
[![Backers on Open Collective](https://opencollective.com/galio/backers/badge.svg)](#backers) 
[![Sponsors on Open Collective](https://opencollective.com/galio/sponsors/badge.svg)](#sponsors) 

<p align="center">
  <img src="assets/galio_thumbnail.jpg">
</p>

Galio is a 100% free and open source project, licensed under MIT License. You'll be building Android and iOS apps in style. Galio will always remain free to use and it is powered by a massive world-wide community.
It comes with a lot of carefully crafted, ready to be used components and a beautiful typography. Galio has a gorgeous base theme that adapts to each project. 
Built with real app examples, component demos, guides, and how-to's to get you up and running with mobile apps faster than ever before.

## Table of Contents
* [Quick start](#quick-start)
* [Components](#components)
* [Documentation](#documentation)
* [Resources](#resources)
* [Reporting Issues](#reporting-issues)
* [Licensing](#licensing)

<p align="center">
  <img src="https://raw.githubusercontent.com/galio-org/galio-org.github.io/master/img/readme3.jpg">
</p>

## Quick Start

#### 1. Project Setup

Go ahead and install the app version of Galio in order to play around with our components and screens!

```bash
git clone https://github.com/galio-org/galio.git
cd galio
git checkout examples
npm install or yarn install
```

#### 2. Project testing
Terminal cli: ```expo start```

After initializing your local server you are now able to test the app inside your simulator by running: `npm run ios` or `yarn run ios` (or try an Android simulator)

Use our iOS or Android app directly on your physical device by running it inside Expo! 

[Expo iOS app](https://itunes.apple.com/us/app/expo-client/id982107779?mt=8)

[Expo Android app](https://play.google.com/store/apps/details?id=host.exp.exponent&hl=en)

#### 3. SDK library instructions
Use our awesome components inside your own projects by running: 
```bash
npm install galio-framework
```
or
```sh
yarn add galio-framework
```
Import our UI components to your screens:
```js
import { Block, Button, Card, Icon, Input, NavBar, Text } from 'galio-framework';
```

## Components

Under Galio's belt:

* Block
* Button
* Card
* Checkbox
* Icon
* Input
* NavBar
* Radio
* Slider
* Text
* Switch
* GalioTheme

## Documentation

The documentation for Galio is hosted at our [our website](https://galio.io/docs?ref=galio-repo)

## Resources

* Website: <https://galio.io?ref=galio-repo>
* Expo: <https://expo.io>
* Issues: [GitHub Issues Page](https://github.com/galio-org/galio/issues)


## Reporting Issues

We use GitHub Issues as the official bug tracker for Galio. Here are some advices for our users that want to report an issue:

1. Make sure that you are using the latest version of Galio. Check for your fork's master branch status and see if it's up to date with the upstream/master (our repository)
2. Provide us with reproductible steps for the issue.
3. Some issues may be platform specific, so specifying what platform and if it's a simulator or a hardware device will help a lot.

## Contributors

This project exists thanks to all the people who contribute. [[Contribute](CONTRIBUTING.md)].
<a href="https://github.com/galio-org/galio/contributors"><img src="https://opencollective.com/galio/contributors.svg?width=890&button=false" /></a>


## Backers

Thank you to all our backers! 🙏 [[Become a backer](https://opencollective.com/galio#backer)]

<a href="https://opencollective.com/galio#backers" target="_blank"><img src="https://opencollective.com/galio/backers.svg?width=890"></a>


## Sponsors

Support this project by becoming a sponsor. Your logo will show up here with a link to your website. [[Become a sponsor](https://opencollective.com/galio#sponsor)]

<a href="https://opencollective.com/galio/sponsor/0/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/0/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/1/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/1/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/2/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/2/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/3/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/3/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/4/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/4/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/5/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/5/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/6/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/6/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/7/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/7/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/8/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/8/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/9/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/9/avatar.svg"></a>

## Licensing

* Licensed under MIT (<https://github.com/galio-org/galio/blob/master/LICENSE>)

© 2019 [Galio](https://galio.io?ref=galio-repo), made with 💚 for the community.

==> galio-framework-0.5.4.tgz: package/README.md <==
# [Galio](https://www.galio.io) ![GitHub package.json version](https://img.shields.io/github/package-json/v/galio-org/galio.svg) [![Tweet](https://img.shields.io/twitter/url/http/shields.io.svg?style=social&logo=twitter)](https://twitter.com/home?status=Galio,%20a%20free%20and%20beautiful%20UI%20framework%20https%3A//galio.io/%20%23reactnative%20%23react%20%23design%20%23developers%20%23freebie%20via%20%40galioframework)

[![GitHub issues](https://img.shields.io/github/issues/galio-org/galio.svg?style=popout)](https://github.com/galio-org/galio/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/galio-org/galio.svg)](https://github.com/galio-org/galio/issues?q=is%3Aissue+is%3Aclosed)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/galio-org/galio.svg)](https://github.com/galio-org/galio/pulls)
[![GitHub closed pull requests](https://img.shields.io/github/issues-pr-closed/galio-org/galio.svg)](https://github.com/galio-org/galio/pulls?q=is%3Apr+is%3Aclosed)
[![Gitter](https://badges.gitter.im/NIT-dgp/General.svg)](https://gitter.im/galio-community)
[![npm](https://img.shields.io/npm/dm/galio-framework.svg)](https://www.npmjs.com/package/galio-framework)
[![Backers on Open Collective](https://opencollective.com/galio/backers/badge.svg)](#backers) 
[![Sponsors on Open Collective](https://opencollective.com/galio/sponsors/badge.svg)](#sponsors) 

<p align="center">
  <img src="assets/galio-logo.png">
  <p align="center">Galio is one of the coolest UI libraries you could ever use, licensed under MIT. Carefully crafted by developers for developers. Ready-made components, typography, and a gorgeous base theme that is easily adaptable to each project.</p>
</p>

## Table of Contents
* [Quick start](#quick-start)
* [Components](#components)
* [Documentation](#documentation)
* [Resources](#resources)
* [Reporting Issues](#reporting-issues)
* [Licensing](#licensing)

<p align="center">
  <img src="https://raw.githubusercontent.com/galio-org/galio-org.github.io/master/img/readme3.jpg">
  <img src="https://i.imgur.com/8kcSRNl.png">
  <img src="https://i.imgur.com/KLM1Zbw.png">
</p>

## Quick Start

#### 1. Project Setup

Go ahead and install the app version of Galio in order to play around with our components and screens!

```bash
git clone https://github.com/galio-org/galio.git
cd galio
git checkout examples
npm install or yarn install
```

#### 2. Project testing
Terminal cli: ```expo start```

After initializing your local server you are now able to test the app inside your simulator by running: 
```npm run ios``` or 
```yarn run ios```
(or try an Android simulator)

Use our iOS or Android app directly on your physical device by running it inside Expo! 

[Expo iOS app](https://itunes.apple.com/us/app/expo-client/id982107779?mt=8)

[Expo Android app](https://play.google.com/store/apps/details?id=host.exp.exponent&hl=en)

#### 3. SDK library instructions
Use our awesome components inside your own projects by running: 
```bash
npm install galio-framework
```
or
```sh
yarn add galio-framework
```
Import our UI components to your screens:
```js
import { Block, Button, Card, Icon, Input, NavBar, Text } from 'galio-framework';
```

## Components

Under Galio's belt:

* Block
* Button
* Card
* Checkbox
* Icon
* Input
* NavBar
* Radio
* Slider
* Text
* Switch
* GalioTheme

## Documentation

The documentation for Galio is hosted at our [our website](https://galio.io/docs?ref=galio-repo)

## Resources

* Website: [galio.io](https://galio.io?ref=galio-repo)
* Expo: [expo.io](https://expo.io?ref=galio-repo)
* Built with Galio: [Galio Apps](https://galio.io/built-with-galio)
* Issues: [GitHub Issues Page](https://github.com/galio-org/galio/issues)


## Reporting Issues

We use GitHub Issues as the official bug tracker for Galio. Here are some advices for our users that want to report an issue:

1. Make sure that you are using the latest version of Galio. Check for your fork's master branch status and see if it's up to date with the upstream/master (our repository)
2. Provide us with reproductible steps for the issue.
3. Some issues may be platform specific, so specifying what platform and if it's a simulator or a hardware device will help a lot.

## Contributors

This project exists thanks to all the people who contribute. [[Contribute](CONTRIBUTING.md)].
<a href="https://github.com/galio-org/galio/contributors"><img src="https://opencollective.com/galio/contributors.svg?width=890&button=false" /></a>


## Backers

Thank you to all our backers! 🙏 [[Become a backer](https://opencollective.com/galio#backer)]

<a href="https://opencollective.com/galio#backers" target="_blank"><img src="https://opencollective.com/galio/backers.svg?width=890"></a>


## Sponsors

Support this project by becoming a sponsor. Your logo will show up here with a link to your website. [[Become a sponsor](https://opencollective.com/galio#sponsor)]

<a href="https://opencollective.com/galio/sponsor/0/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/0/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/1/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/1/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/2/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/2/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/3/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/3/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/4/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/4/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/5/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/5/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/6/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/6/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/7/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/7/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/8/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/8/avatar.svg"></a>
<a href="https://opencollective.com/galio/sponsor/9/website" target="_blank"><img src="https://opencollective.com/galio/sponsor/9/avatar.svg"></a>

## Licensing

* Licensed under MIT (<https://github.com/galio-org/galio/blob/master/LICENSE>)

© 2019 [Galio](https://galio.io?ref=galio-repo), made with 💚 for the community.
